package com.ruoyi.project.system.mapper;

import java.util.List;
import com.ruoyi.project.system.domain.Notify;

/**
 * 通知管理Mapper接口
 *
 * @author yf
 * @date 2020-07-07
 */
public interface NotifyMapper
{
    /**
     * 查询通知管理
     *
     * @param id 通知管理ID
     * @return 通知管理
     */
    public Notify selectNotifyById(Long id);

    /**
     * 已发通知列表
     *
     * @param notify 通知管理
     * @return 通知管理集合
     */
    public List<Notify> selectNotifyList(Notify notify);

    /**
     * 收取通知列表
     *
     * @param notify 通知管理
     * @return 通知管理集合
     */
    public List<Notify> selectRecvNotifyList(Notify notify);

    /**
     * 新增通知管理
     *
     * @param notify 通知管理
     * @return 结果
     */
    public int insertNotify(Notify notify);

    /**
     * 修改通知管理
     *
     * @param notify 通知管理
     * @return 结果
     */
    public int updateNotify(Notify notify);

    /**
     * 删除通知管理
     *
     * @param id 通知管理ID
     * @return 结果
     */
    public int deleteNotifyById(Long id);

    /**
     * 批量删除通知管理
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteNotifyByIds(Long[] ids);
}
